==> nextcloud-25.0.8.tgz: nextcloud/apps/serverinfo/l10n/ca.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informació del processador no disponible",
    "Load average: {cpu} (last minute)" : "Mitjana de càrrega: {cpu} (última hora)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Total: {memTotalBytes}/Ús actual: {memUsageBytes}",
    "RAM info not available" : "La informació de la RAM no està disponible",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Total: {swapTotalBytes}/Ús actual: {swapUsageBytes}",
    "SWAP info not available" : "La informació de SWAP no està disponible",
    "Not supported!" : "No suportat!",
    "Press ⌘-C to copy." : "Premeu ⌘-C per còpia.",
    "Press Ctrl-C to copy." : "Premeu Ctrl-C per còpia.",
    "System" : "Sistema",
    "Monitoring" : "Monitorització",
    "Monitoring app with useful server information" : "Aplicació per monitoritzar amb informació útil del servidor",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Proporciona informació útil del servidor, com ara la càrrega del processador, l’ús de memòria RAM, l’ús del disc, el nombre d’usuaris, etc.",
    "Operating System:" : "Sistema operatiu:",
    "CPU:" : "CPU:",
    "Unknown Processor" : "Processador desconegut",
    "Memory:" : "Memòria:",
    "Server time:" : "Hora del servidor:",
    "Uptime:" : "Temps de funcionament:",
    "Temperature" : "Temperatura",
    "Load" : "Càrrega",
    "Memory" : "Memòria",
    "Disk" : "Disc",
    "Mount:" : "Muntatge:",
    "Filesystem:" : "Sistema de fitxers:",
    "Size:" : "Mida:",
    "Available:" : "Disponible:",
    "Used:" : "Utilitzat:",
    "You will get a notification once one of your disks is nearly full." : "Rebreu una notificació quan un dels vostres discs estigui gairebé ple.",
    "Files:" : "FItxers:",
    "Storages:" : "Emmagatzematges:",
    "Free Space:" : "Espai lliure:",
    "Network" : "Xarxa",
    "Hostname:" : "Nom de màquina:",
    "DNS:" : "DNS:",
    "Gateway:" : "Passarel·la:",
    "Status:" : "Estat:",
    "Speed:" : "Velocitat:",
    "Duplex:" : "Dúplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Usuaris actius",
    "Total users:" : "Total d'usuaris:",
    "24 hours:" : "24 hores:",
    "1 hour:" : "1 hora:",
    "5 mins:" : "5 minuts:",
    "Shares" : "Element compartits",
    "Users:" : "Usuaris:",
    "Groups:" : "Grups:",
    "Links:" : "Enllaços:",
    "Emails:" : "Correus electrònics:",
    "Federated sent:" : "Enviat federat:",
    "Federated received:" : "Federat rebut:",
    "Talk conversations:" : "Converses:",
    "PHP" : "PHP",
    "Version:" : "Versió:",
    "Memory limit:" : "Límit de la Memòria:",
    "Max execution time:" : "Temps màxim de l'execució:",
    "Upload max size:" : "Mida màxima per pujades:",
    "Extensions:" : "Extensions:",
    "Unable to list extensions" : "No es poden llistar les extensions",
    "Database" : "Base de dades",
    "Type:" : "Tipus:",
    "External monitoring tool" : "Eina externa de monitorització",
    "You can connect an external monitoring tool by using this end point:" : "Podeu connectar una eina externa de monitorització fent servir aquest punt final:",
    "Copy" : "Copia",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Afegint \"?format=json\" al final de la URL rebreu el resultat en format JSON.",
    "To use an access token, please generate one then set it using the following command:" : "Per utilitzar un testimoni d'accés, genereu-ne un i configureu-lo amb l'ordre següent:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "A continuació, passeu el testimoni amb la capçalera \"NC-Token\" quan consulteu l’adreça URL anterior."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.12.tgz: nextcloud/apps/serverinfo/l10n/ca.js <==
OC.L10N.register(
    "serverinfo",
    {
    "CPU info not available" : "Informació del processador no disponible",
    "Load average: {cpu} (last minute)" : "Mitjana de càrrega: {cpu} (última hora)",
    "RAM: Total: {memTotalBytes}/Current usage: {memUsageBytes}" : "RAM: Total: {memTotalBytes}/Ús actual: {memUsageBytes}",
    "RAM info not available" : "La informació de la RAM no està disponible",
    "SWAP: Total: {swapTotalBytes}/Current usage: {swapUsageBytes}" : "SWAP: Total: {swapTotalBytes}/Ús actual: {swapUsageBytes}",
    "SWAP info not available" : "La informació de SWAP no està disponible",
    "Not supported!" : "No suportat!",
    "Press ⌘-C to copy." : "Premeu ⌘-C per còpia.",
    "Press Ctrl-C to copy." : "Premeu Ctrl-C per còpia.",
    "System" : "Sistema",
    "Monitoring" : "Monitorització",
    "Monitoring app with useful server information" : "Aplicació per monitoritzar amb informació útil del servidor",
    "Provides useful server information, such as CPU load, RAM usage, disk usage, number of users, etc." : "Proporciona informació útil del servidor, com ara la càrrega del processador, l’ús de memòria RAM, l’ús del disc, el nombre d’usuaris, etc.",
    "Operating System:" : "Sistema operatiu:",
    "CPU:" : "CPU:",
    "Unknown Processor" : "Processador desconegut",
    "Memory:" : "Memòria:",
    "Server time:" : "Hora del servidor:",
    "Uptime:" : "Temps de funcionament:",
    "Temperature" : "Temperatura",
    "Load" : "Càrrega",
    "Memory" : "Memòria",
    "Disk" : "Disc",
    "Mount:" : "Muntatge:",
    "Filesystem:" : "Sistema de fitxers:",
    "Size:" : "Mida:",
    "Available:" : "Disponible:",
    "Used:" : "Utilitzat:",
    "Files:" : "FItxers:",
    "Storages:" : "Emmagatzematges:",
    "Free Space:" : "Espai lliure:",
    "Network" : "Xarxa",
    "Hostname:" : "Nom de màquina:",
    "DNS:" : "DNS:",
    "Gateway:" : "Passarel·la:",
    "Status:" : "Estat:",
    "Speed:" : "Velocitat:",
    "Duplex:" : "Dúplex:",
    "MAC:" : "MAC:",
    "IPv4:" : "IPv4:",
    "IPv6:" : "IPv6:",
    "Active users" : "Usuaris actius",
    "Total users:" : "Total d'usuaris:",
    "24 hours:" : "24 hores:",
    "1 hour:" : "1 hora:",
    "5 mins:" : "5 minuts:",
    "Shares" : "Elements compartits",
    "Users:" : "Usuaris:",
    "Groups:" : "Grups:",
    "Links:" : "Enllaços:",
    "Emails:" : "Correus electrònics:",
    "Federated sent:" : "Enviat federat:",
    "Federated received:" : "Federat rebut:",
    "Talk conversations:" : "Converses:",
    "PHP" : "PHP",
    "Version:" : "Versió:",
    "Memory limit:" : "Límit de la Memòria:",
    "Max execution time:" : "Temps màxim de l'execució:",
    "Upload max size:" : "Mida màxima per pujades:",
    "Extensions:" : "Extensions:",
    "Unable to list extensions" : "No es poden llistar les extensions",
    "Database" : "Base de dades",
    "Type:" : "Tipus:",
    "External monitoring tool" : "Eina externa de monitorització",
    "You can connect an external monitoring tool by using this end point:" : "Podeu connectar una eina externa de monitorització fent servir aquest punt final:",
    "Copy" : "Copia",
    "Appending \"?format=json\" at the end of the URL gives you the result in JSON." : "Afegint \"?format=json\" al final de la URL rebreu el resultat en format JSON.",
    "To use an access token, please generate one then set it using the following command:" : "Per utilitzar un testimoni d'accés, genereu-ne un i configureu-lo amb l'ordre següent:",
    "Then pass the token with the \"NC-Token\" header when querying the above URL." : "A continuació, passeu el testimoni amb la capçalera \"NC-Token\" quan consulteu l’adreça URL anterior.",
    "You will get a notification once one of your disks is nearly full." : "Rebreu una notificació quan un dels vostres discs estigui gairebé ple."
},
"nplurals=2; plural=(n != 1);");
